@@ -11,11 +11,14 @@ import sys, shutil, os
 from threading import Thread
 from glob import glob
 
-import sip
 from PyQt5.Qt import (
     QDialog, QApplication, QLabel, QVBoxLayout, QDialogButtonBox, Qt,
     pyqtSignal, QListWidget, QListWidgetItem, QSize, QPixmap, QStyledItemDelegate
 )
+try:
+    from PyQt5 import sip
+except ImportError:
+    import sip
 
 from calibre import as_unicode
 from calibre.ebooks.metadata.pdf import page_images
