@@ -84,7 +84,7 @@ class Kindle(Device):
 
     output_profile = 'kindle'
     output_format  = 'MOBI'
-    name = 'Kindle Touch/1-4'
+    name = 'Kindle Basic (all models)'
     manufacturer = 'Amazon'
     id = 'kindle'
 
@@ -125,7 +125,7 @@ class KindleFire(KindleDX):
 class KindlePW(Kindle):
     name = 'Kindle PaperWhite'
     id = 'kindle_pw'
-    output_profile = 'kindle_pw'
+    output_profile = 'kindle_pw3'
 
 
 class KindleVoyage(Kindle):
@@ -685,7 +685,7 @@ class LibraryPage(QWizardPage, LibraryUI):
     def change_language(self, idx):
         prefs['language'] = str(self.language.itemData(self.language.currentIndex()) or '')
         import __builtin__
-        __builtin__.__dict__['_'] = lambda(x): x
+        __builtin__.__dict__['_'] = lambda x: x
         from calibre.utils.localization import set_translators
         from calibre.gui2 import qt_app
         from calibre.ebooks.metadata.book.base import reset_field_metadata
@@ -726,8 +726,7 @@ class LibraryPage(QWizardPage, LibraryUI):
         x = choose_dir(self, 'database location dialog',
                          _('Select location for books'))
         if x:
-            if (iswindows and len(x) >
-                    LibraryDatabase.WINDOWS_LIBRARY_PATH_LIMIT):
+            if (iswindows and len(x) > LibraryDatabase.WINDOWS_LIBRARY_PATH_LIMIT):
                 return error_dialog(self, _('Too long'),
                     _('Path to library too long. Must be less than'
                     ' %d characters.')%(LibraryDatabase.WINDOWS_LIBRARY_PATH_LIMIT),
@@ -760,14 +759,10 @@ class LibraryPage(QWizardPage, LibraryUI):
         self.default_library_name = None
         if not lp:
             fname = _('Calibre Library')
-            base = os.path.expanduser(u'~')
-            if iswindows:
-                try:
-                    x = winutil.special_folder_path(winutil.CSIDL_PERSONAL)
-                except ValueError:
-                    x = QDir.homePath().replace('/', os.sep)
-                if x and os.access(x, os.W_OK):
-                    base = x
+            try:
+                base = os.path.expanduser(u'~')
+            except ValueError:
+                base = QDir.homePath().replace('/', os.sep)
 
             lp = os.path.join(base, fname)
             self.default_library_name = lp
@@ -776,7 +771,10 @@ class LibraryPage(QWizardPage, LibraryUI):
                     os.makedirs(lp)
                 except:
                     traceback.print_exc()
-                    lp = os.path.expanduser(u'~')
+                    try:
+                        lp = os.path.expanduser(u'~')
+                    except ValueError:
+                        lp = QDir.homePath().replace('/', os.sep)
         self.location.setText(lp)
         # Hide the library location settings if we are a portable install
         for x in ('location', 'button_change', 'libloc_label1',
@@ -846,7 +844,7 @@ class Wizard(QWizard):
 
     def __init__(self, parent):
         QWizard.__init__(self, parent)
-        self.setWindowTitle(__appname__+' '+_('welcome wizard'))
+        self.setWindowTitle(__appname__+' '+_('Welcome wizard'))
         self.setPixmap(self.LogoPixmap, QIcon(I('library.png')).pixmap(48, 48))
         self.setWizardStyle(self.ModernStyle)
         self.device_page = DevicePage()
