@@ -1,6 +1,7 @@
 #!/usr/bin/env python2
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 from __future__ import with_statement
+from __future__ import print_function
 
 __license__   = 'GPL v3'
 __copyright__ = '2010, Kovid Goyal <kovid@kovidgoyal.net>'
@@ -10,6 +11,7 @@ import os
 
 from calibre.utils.date import isoformat, DEFAULT_DATE
 
+
 class SchemaUpgrade(object):
 
     def __init__(self):
@@ -20,7 +22,7 @@ class SchemaUpgrade(object):
             if meth is None:
                 break
             else:
-                print 'Upgrading database to version %d...'%(uv+1)
+                print('Upgrading database to version %d...'%(uv+1))
                 meth()
                 self.user_version = uv+1
 
@@ -415,6 +417,7 @@ class SchemaUpgrade(object):
         'Cache has_cover'
         self.conn.execute('ALTER TABLE books ADD COLUMN has_cover BOOL DEFAULT 0')
         data = self.conn.get('SELECT id,path FROM books', all=True)
+
         def has_cover(path):
             if path:
                 path = os.path.join(self.library_path, path.replace('/', os.sep),
